==> manydhcp2.5.2.tar.bz2: manydhcp/addresses/on.php <==
<?php
  ///////////////////////////////////////////////////
  //Включение ip-адреса из статистики
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  $title=$titlepage = $TEXT['addr-title-edit'];
  $delimiter = ".";

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}

  if(strlen($_GET['rows'])>12) {puterror($result2['skin'],$TEXT['error-log10']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['srv_id'])>5) {puterror($result2['skin'],$TEXT['error-srv22']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['name'])>255) {puterror($result2['skin'],$TEXT['error-addr2']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['descr'])>255) {puterror($result2['skin'],$TEXT['error-addr3']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['ip_addr'])>15) {puterror($result2['skin'],$TEXT['error-addr5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['hw'])>17) {puterror($result2['skin'],$TEXT['error-addr7']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['vkl'])>1) {puterror($result2['skin'],$TEXT['error-srv15']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['vkl_ch'])>5) {puterror($result2['skin'],$TEXT['error-srv15']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['srv_ch'])>5) {puterror($result2['skin'],$TEXT['error-srv15']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['ip_id'])) {puterror($result2['skin'],$TEXT['error-srv21']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['ip_id'])>255) {puterror($result2['skin'],$TEXT['error-srv22']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['ip_id'] = rep($_GET['ip_id']);

  $query10 = "SELECT name, descr, ip_addr FROM `tbl_ip` WHERE `ip_id`='".$_GET['ip_id']."' ";
  $result10 = mysql_query($query10);
   if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
      $result_addr = mysql_fetch_array($result10);

 $addr = explode($delimiter,$result_addr['ip_addr'],4);
      $oct1 = substr($addr['0'],0,1);
       if($oct1 == '0')
        {
         $oct_res1 = substr($addr['0'],1,1);
         if($oct_res1 == '0')
          {
           $oct_result1 = substr($addr['0'],2,3);
          } else $oct_result1 = substr($addr['0'],1,3);
         } else $oct_result1 = $addr['0'];

       $oct2 = substr($addr['1'],0,1);
        if($oct2 == '0')
         {
          $oct_res2 = substr($addr['1'],1,1);
           if($oct_res2 == '0')
            {
             $oct_result2 = substr($addr['1'],2,3);
            } else $oct_result2 = substr($addr['1'],1,3);
          } else $oct_result2 = $addr['1'];

      $oct3 = substr($addr['2'],0,1);
       if($oct3 == '0')
        {
         $oct_res3 = substr($addr['2'],1,1);
         if($oct_res3 == '0')
         {
         $oct_result3 = substr($addr['2'],2,3);
         } else $oct_result3 = substr($addr['2'],1,3);
        } else $oct_result3 = $addr['2'];

      $oct4 = substr($addr['3'],0,1);
       if($oct4 == '0')
        {
         $oct_res4 = substr($addr['3'],1,1);
         if($oct_res4 == '0')
          {
           $oct_result4 = substr($addr['3'],2,3);
          } else $oct_result4 = substr($addr['3'],1,3);
         } else $oct_result4 = $addr['3'];
     $addr_iskh = $oct_result1.".".$oct_result2.".".$oct_result3.".".$oct_result4;

  $query = "UPDATE `tbl_ip` SET `vkl_ip`='1' WHERE `ip_id`='".$_GET['ip_id']."' ";
  if(mysql_query($query))
  {
    //*************************************
    //Информация для лога
    $ip = $_SERVER['REMOTE_ADDR'];
    $doing = $TEXT['addr-vkl-tit'];
    $what = $addr_iskh." (".$result_addr['name'].", &laquo;".$result_addr['descr']."&raquo;) - ".$TEXT['addr-vkluchit3']."<br />".$TEXT['log-id'].$_GET['ip_id'];
    $who = $result2['familiya']." ".$result2['name'];
    //*************************************

    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysql_query($query2))
           {
          echo "<html><head>
          <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php?name=".$_GET['name']."&amp;descr=".$_GET['descr']."&amp;ip_addr=".$_GET['ip_addr']."&amp;hw=".$_GET['hw']."&amp;rows=".$_GET['rows']."&amp;srv_id=".$_GET['srv_id']."&amp;srv_ch=".$_GET['srv_ch']."&amp;vkl_ch=".$_GET['vkl_ch']."&amp;vkl=".$_GET['vkl']."' />
          </head></html>";
      } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.8.2.tar.bz2: manydhcp/addresses/on.php <==
<?php
  ///////////////////////////////////////////////////
  //Включение ip-адреса из статистики
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['addr-title-edit'];
  $delimiter = ".";

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}

  if(strlen($_GET['rows'])>12) {puterror($result2['skin'],$TEXT['error-log10']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['srv_id'])>5) {puterror($result2['skin'],$TEXT['error-srv22']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['name'])>255) {puterror($result2['skin'],$TEXT['error-addr2']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['descr'])>255) {puterror($result2['skin'],$TEXT['error-addr3']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['ip_addr'])>15) {puterror($result2['skin'],$TEXT['error-addr5']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['hw'])>17) {puterror($result2['skin'],$TEXT['error-addr7']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['vkl'])>1) {puterror($result2['skin'],$TEXT['error-srv15']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['vkl_ch'])>5) {puterror($result2['skin'],$TEXT['error-srv15']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['srv_ch'])>5) {puterror($result2['skin'],$TEXT['error-srv15']); require_once "../utils/bottom_adm.php"; exit();}

  if(empty($_GET['ip_id'])) {puterror($result2['skin'],$TEXT['error-srv21']); require_once "../utils/bottom_adm.php"; exit();}
  if(strlen($_GET['ip_id'])>255) {puterror($result2['skin'],$TEXT['error-srv22']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['ip_id'] = rep($_GET['ip_id']);

  $query10 = "SELECT name, descr, ip_addr FROM `tbl_ip` WHERE `ip_id`='".$_GET['ip_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
   if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
      $result_addr = mysqli_fetch_array($result10,MYSQLI_ASSOC);

 $addr = explode($delimiter,$result_addr['ip_addr'],4);
      $oct1 = substr($addr['0'],0,1);
       if($oct1 == '0')
        {
         $oct_res1 = substr($addr['0'],1,1);
         if($oct_res1 == '0')
          {
           $oct_result1 = substr($addr['0'],2,3);
          } else {$oct_result1 = substr($addr['0'],1,3);}
         } else {$oct_result1 = $addr['0'];}

       $oct2 = substr($addr['1'],0,1);
        if($oct2 == '0')
         {
          $oct_res2 = substr($addr['1'],1,1);
           if($oct_res2 == '0')
            {
             $oct_result2 = substr($addr['1'],2,3);
            } else {$oct_result2 = substr($addr['1'],1,3);}
          } else {$oct_result2 = $addr['1'];}

      $oct3 = substr($addr['2'],0,1);
       if($oct3 == '0')
        {
         $oct_res3 = substr($addr['2'],1,1);
         if($oct_res3 == '0')
         {
         $oct_result3 = substr($addr['2'],2,3);
         } else {$oct_result3 = substr($addr['2'],1,3);}
        } else {$oct_result3 = $addr['2'];}

      $oct4 = substr($addr['3'],0,1);
       if($oct4 == '0')
        {
         $oct_res4 = substr($addr['3'],1,1);
         if($oct_res4 == '0')
          {
           $oct_result4 = substr($addr['3'],2,3);
          } else {$oct_result4 = substr($addr['3'],1,3);}
         } else {$oct_result4 = $addr['3'];}
     $addr_iskh = $oct_result1.".".$oct_result2.".".$oct_result3.".".$oct_result4;

  $query = "UPDATE `tbl_ip` SET `vkl_ip`='1' WHERE `ip_id`='".$_GET['ip_id']."' ";
  if(mysqli_query($dbcnx,$query))
  {
    //*************************************
    //Информация для лога
    $ip = $_SERVER['REMOTE_ADDR'];
    $doing = $TEXT['addr-vkl-tit'];
    $what = $addr_iskh." (".$result_addr['name'].", &laquo;".$result_addr['descr']."&raquo;) - ".$TEXT['addr-vkluchit3']."<br />".$TEXT['log-id'].$_GET['ip_id'];
    $who = $result2['familiya']." ".$result2['name'];
    //*************************************

    $query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
        if(mysqli_query($dbcnx,$query2))
           {
          echo "<html><head>
          <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=index.php?name=".$_GET['name']."&amp;descr=".$_GET['descr']."&amp;ip_addr=".$_GET['ip_addr']."&amp;hw=".$_GET['hw']."&amp;rows=".$_GET['rows']."&amp;srv_id=".$_GET['srv_id']."&amp;srv_ch=".$_GET['srv_ch']."&amp;vkl_ch=".$_GET['vkl_ch']."&amp;vkl=".$_GET['vkl']."' />
          </head></html>";
      } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
  } else {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
  require_once "../utils/bottom_adm.php";
?>
